import QtQuick 1.0
import QtMultimediaKit 1.1
import QtWebKit 1.0
import Qt.labs.folderlistmodel 1.0
import "globals.js" as GlobalScript

Rectangle {
    id: screen
    width: 800
    height: 480
    Grid {
        columns: 2
        spacing: 0

        Rectangle {
            id: video;
            color: "black";
            width: 600;
            height: 432

            ListModel {
                    id: videoFiles
                     ListElement {
                             file: "video/video1.wmv"
                     }
                     ListElement {
                             file: "video/video2.mpg"
                     }
                     ListElement {
                             file: "video/video3.webm"
                     }
                     ListElement {
                             file: "video/video4.wmv"
                     }
                     ListElement {
                             file: "video/video5.wmv"
                     }
            }

            Video {
                id: videofile
                playing: true
                source: videoFiles.get(GlobalScript.iVideoIndex).file
                width: 600
                height: 432
                opacity: 0.9
                focus: true
                onStopped: { // To loop the video
                    source = videoFiles.get(GlobalScript.iVideoIndex).file
                    console.debug("Video: " + videoFiles.get(GlobalScript.iVideoIndex).file)
                    videofile.play()
                    GlobalScript.iVideoIndex =  (GlobalScript.iVideoIndex + 1) % 5;
                }

            }
            MouseArea { // For debug only: Click to stop video to make it switch to the next one
                anchors.fill: parent
                onClicked: {
                    videofile.stop()
                }
            }
        }
        Rectangle {
            id: picture; width: 200; height: 432
            anchors.left: video.right
            ListModel {
                    id: picFiles
                     ListElement {
                             file: "pic/pic1.jpg"
                     }
                     ListElement {
                             file: "pic/pic2.jpg"
                     }
                     ListElement {
                             file: "pic/pic3.jpg"
                     }
                     ListElement {
                             file: "pic/pic4.jpg"
                     }
                     ListElement {
                             file: "pic/pic5.jpg"
                     }
            }

            Image {
                source: picFiles.get(GlobalScript.iPicIndex).file
                Timer {
                    interval: 5000; // 5 Seconds
                    running: true;
                    repeat: true
                    onTriggered: {
                        parent.visible = false
                        parent.source = picFiles.get(GlobalScript.iPicIndex).file
                        parent.visible = true
                        console.debug("Picture: " + picFiles.get(GlobalScript.iPicIndex).file)
                        GlobalScript.iPicIndex =  (GlobalScript.iPicIndex + 1) % 5;
                    }
                }
            }
        }
        Rectangle {
            id: text
            width: 800; height: 48
            color: "blue"
            XmlListModel {
                 id: feedModel
                 source: "http://twitter.com/statuses/user_timeline/114751985.rss"
                 query: "/rss/channel/item"
                 XmlRole { name: "title"; query: "title/string()" }
            }
            ListView {
                 id: rss
                 width: 800; height: 48
                 model: feedModel
                 delegate: ScrollingText {
                     id:scrolltext
                     width: 800
                     height: 48
                     text: title // "Qt Quick Digital Signage Demo"
                 }
            }

/* Method 2: Webview (issue with white border)
            WebView {
                    width: 800; height: 48
                    preferredWidth: 800; preferredHeight: 46
                    anchors.top: video.bottom
                    // Marquee code generated with http://www.quackit.com/html/html_generators/html_marquee_generator.cfm
                    html: "<style type=\"text/css\">
                               .html-marquee {height:48px;width:800px;background-color:3333FF;font-family:Verdana;font-size:24pt;color:FFFF33;font-weight:bold;}
                           </style>
                           <marquee class=\"html-marquee\" direction=\"left\" behavior=\"scroll\" scrollamount=\"6\" >Qt Quick Digital Signage Demo</marquee>"
           }
*/
       }
    }
}
